bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOMoments.compute_fixed_moments
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOMoments.compute_fixed_moments